@@ -23,6 +23,7 @@ class ArtistModel : public AbstractYTMusicModel
 
     Q_PROPERTY(QString title READ title NOTIFY titleChanged)
     Q_PROPERTY(QUrl thumbnailUrl READ thumbnailUrl NOTIFY thumbnailUrlChanged)
+    Q_PROPERTY(QUrl webUrl READ webUrl NOTIFY webUrlChanged)
 
 public:
     enum Type {
@@ -56,6 +57,9 @@ public:
     QUrl thumbnailUrl() const;
     Q_SIGNAL void thumbnailUrlChanged();
 
+    QUrl webUrl() const;
+    Q_SIGNAL void webUrlChanged();
+
     Q_INVOKABLE void triggerItem(int row);
 
     Q_SIGNAL void openAlbum(const QString &browseId);
