@@ -19,6 +19,9 @@
 #include "errorhandler.h"
 #include "playlistmodel.h"
 #include "playerutils.h"
+#include "library.h"
+
+#include "asyncdatabase.h"
 
 constexpr auto URI = "org.kde.ytmusic";
 
@@ -51,6 +54,9 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterSingletonType<PlayerUtils>(URI, 1, 0, "PlayerUtils", [](QQmlEngine *, QJSEngine *) {
         return new PlayerUtils();
     });
+    qmlRegisterSingletonInstance<Library>(URI, 1, 0, "Library", &Library::instance());
+    qmlRegisterType<ThumbnailSource>(URI, 1, 0, "ThumbnailSource");
+    qmlRegisterAnonymousType<FavouriteWatcher>(URI, 1);
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
     engine.load(QUrl(QStringLiteral("qrc:///main.qml")));
